@@ -1,12 +1,12 @@
-import sys
-import argparse
-import unittest
-import collections
-import pprint
-import math
+import sys as _sys
+import argparse as _argparse
+import unittest as _unittest
+import collections as _collections
+import pprint as _pprint
+import math as _math
 
 
-__version__ = '0.0.8'
+__version__ = '0.0.10'
 
 
 class Error(Exception):
@@ -16,22 +16,40 @@ class Error(Exception):
 TICK_INTERVAL_PADDING_RATIO = 0.1
 
 
-def memo1(f):
+def memoize(f):
     cache = {}
-    def retf(x):
-        if x in cache:
-            return cache[x]
+    def retf(*args):
+        if args in cache:
+            return cache[args]
         else:
-            retv = f(x)
-            cache[x] = retv
+            retv = f(*args)
+            cache[args] = retv
             return retv
     retf.cache = cache
     return retf
 
 
+def profiled_memoize(f):
+    cache = {}
+    profile = {'new': 0,
+               'hit': 0}
+    def retf(*args):
+        if args in cache:
+            profile['hit'] += 1
+            return cache[args]
+        else:
+            profile['new'] += 1
+            retv = f(*args)
+            cache[args] = retv
+            return retv
+    retf.cache = cache
+    retf.profile = profile
+    return retf
+
+
 def _get_interval(lx):
     assert lx > 0
-    dx = 10**(math.ceil(math.log10(lx)) - 1)
+    dx = 10**(_math.ceil(_math.log10(lx)) - 1)
     if lx > 5*dx:
         return dx
     elif lx > 2*dx:
@@ -43,7 +61,7 @@ def _get_interval(lx):
 def _get_lower_limit(x, dx,
                      padding_ratio=TICK_INTERVAL_PADDING_RATIO):
     assert dx > 0
-    lower = math.floor(x/dx)*dx
+    lower = _math.floor(x/dx)*dx
     if x <= lower + dx*padding_ratio:
         lower -= dx
     return lower
@@ -52,7 +70,7 @@ def _get_lower_limit(x, dx,
 def _get_upper_limit(x, dx,
                      padding_ratio=TICK_INTERVAL_PADDING_RATIO):
     assert dx > 0
-    upper = math.ceil(x/dx)*dx
+    upper = _math.ceil(x/dx)*dx
     if x >= upper - dx*padding_ratio:
         upper += dx
     return upper
@@ -68,7 +86,7 @@ def get_tick_configurations(x1, x2,
 
 
 def pp(x):
-    pprint.pprint(x, stream=sys.stderr)
+    _pprint.pprint(x, stream=_sys.stderr)
     return x
 
 
@@ -86,7 +104,7 @@ def flatten(xss):
         yield xss
     else:
         for xs in xss:
-            if isinstance(xs, collections.Iterable):
+            if isinstance(xs, _collections.Iterable):
                 for x in flatten(xs):
                     yield x
             else:
@@ -131,11 +149,11 @@ def make_fixed_format_parser(fields):
     return fixed_format_parser
 
 
-class TestAction(argparse.Action):
+class TestAction(_argparse.Action):
     def __init__(self,
                  option_strings,
-                 dest=argparse.SUPPRESS,
-                 default=argparse.SUPPRESS,
+                 dest=_argparse.SUPPRESS,
+                 default=_argparse.SUPPRESS,
                  help=None):
         super().__init__(option_strings=option_strings,
                          dest=dest,
@@ -145,11 +163,11 @@ class TestAction(argparse.Action):
 
 
     def __call__(self, parser, namespace, values, option_string=None):
-        unittest.main(argv=sys.argv[:1])
+        _unittest.main(argv=_sys.argv[:1])
         parser.exit()
 
 
-class Tester(unittest.TestCase):
+class _Tester(_unittest.TestCase):
     def test__get_interval(self):
         with self.assertRaises(AssertionError):
             _get_interval(-1)
@@ -252,4 +270,4 @@ class Tester(unittest.TestCase):
 
 
 if __name__ == '__main__':
-    unittest.main()
+    _unittest.main()
